@@ -1,15 +1,11 @@
-from pathlib import Path
-
 import numpy as np
 import seaborn as sns
 from matplotlib import pyplot as plt
 from scipy.interpolate import pchip
 
-from sleplet.slepian.slepian_region.slepian_arbitrary import SlepianArbitrary
-from sleplet.utils.plot_methods import save_plot
-from sleplet.utils.wavelet_methods import create_kappas
+from sleplet.slepian import SlepianArbitrary
+from sleplet.wavelet_methods import create_kappas
 
-fig_path = Path(__file__).resolve().parents[3] / "src" / "sleplet" / "figures"
 sns.set(context="paper")
 
 B = 3
@@ -19,9 +15,7 @@ STEP = 0.01
 
 
 def main() -> None:
-    """
-    plots the tiling of the Slepian line
-    """
+    """Plots the tiling of the Slepian line."""
     xlim = L**2
     x = np.arange(xlim)
     xi = np.arange(0, xlim - 1 + STEP, STEP)
@@ -46,7 +40,11 @@ def main() -> None:
     plt.xticks(ticks, ticks)
     plt.xlabel(r"$p$")
     plt.legend()
-    save_plot(fig_path, f"africa_slepian_tiling_L{L}")
+    print(f"Opening: africa_slepian_tiling_L{L}")
+    plt.tight_layout()
+    plt.show(block=False)
+    plt.pause(10)
+    plt.close()
 
 
 if __name__ == "__main__":
