@@ -1,6 +1,9 @@
-from denoising_slepian_mesh import main
+import sys
+from pathlib import Path
 
-from sleplet import logger
+sys.path.append(str(Path(__file__).resolve().parent))
+
+from denoising_slepian_mesh import main  # noqa: E402
 
 MESH_SNR_DICT = {
     "cheetah": -8.64,
@@ -14,5 +17,5 @@ SIGMA = 2
 
 if __name__ == "__main__":
     for mesh, snr in MESH_SNR_DICT.items():
-        logger.info(f"\n\n\ndenoising {mesh}")
+        print(f"\n\n\ndenoising {mesh}")
         main(mesh, snr, SIGMA)
