@@ -1,13 +1,8 @@
-from pathlib import Path
-
 import numpy as np
 import seaborn as sns
 from matplotlib import pyplot as plt
 from numpy import typing as npt
 
-from sleplet.utils.plot_methods import save_plot
-
-fig_path = Path(__file__).resolve().parents[2] / "src" / "sleplet" / "figures"
 sns.set(context="paper")
 
 DELTA_T = 0.001
@@ -16,9 +11,7 @@ LENGTH = 0.512
 
 
 def main() -> None:
-    """
-    plots a Dirac impulse and it's Fourier transform
-    """
+    """Plots a Dirac impulse and it's Fourier transform."""
     size = int(LENGTH / DELTA_T)
     amplitude = np.zeros(size * len(FREQUENCIES))
     for c, f in enumerate(FREQUENCIES):
@@ -26,16 +19,18 @@ def main() -> None:
     plt.plot(amplitude)
     plt.xticks([])
     plt.xlabel(r"$t$")
-    save_plot(fig_path, "ricker_wavelets")
+    print("Opening: ricker_wavelets")
+    plt.tight_layout()
+    plt.show(block=False)
+    plt.pause(10)
+    plt.close()
 
 
 def _ricker(freq: float) -> npt.NDArray[np.float_]:
-    """
-    creates a Ricker wavelet
-    """
+    """Creates a Ricker wavelet."""
     t = np.arange(-LENGTH / 2, (LENGTH - DELTA_T) / 2, DELTA_T)
     return (1.0 - 2.0 * (np.pi**2) * (freq**2) * (t**2)) * np.exp(
-        -(np.pi**2) * (freq**2) * (t**2)
+        -(np.pi**2) * (freq**2) * (t**2),
     )
 
 
