@@ -1,10 +1,9 @@
 import numpy as np
 
-from sleplet import logger
-from sleplet.functions.fp.slepian import Slepian
-from sleplet.plotting.create_plot_sphere import Plot
-from sleplet.utils.region import Region
-from sleplet.utils.slepian_methods import slepian_inverse
+from sleplet.functions import Slepian
+from sleplet.plotting import PlotSphere
+from sleplet.slepian import Region
+from sleplet.slepian_methods import slepian_inverse
 
 L = 16
 NORMALISE = False
@@ -14,14 +13,15 @@ THETA_MAX = 40
 
 def main() -> None:
     """
-    create fig 5.4 from Spatiospectral Concentration on a Sphere by Simons et al 2006
+    Create fig 5.4 from Spatiospectral Concentration on a Sphere
+    by Simons et al 2006.
     """
     region = Region(theta_max=np.deg2rad(THETA_MAX))
     for r in range(RANKS):
-        logger.info(f"plotting rank={r}")
+        print(f"plotting rank={r}")
         slepian_function = Slepian(L, rank=r, region=region)
         f = slepian_inverse(slepian_function.coefficients, L, slepian_function.slepian)
-        Plot(
+        PlotSphere(
             f,
             L,
             slepian_function.name,
