@@ -1,14 +1,10 @@
-from pathlib import Path
-
 import numpy as np
 import seaborn as sns
 from matplotlib import pyplot as plt
 from scipy.interpolate import pchip
 
-from sleplet.utils.plot_methods import save_plot
-from sleplet.utils.wavelet_methods import create_kappas
+from sleplet.wavelet_methods import create_kappas
 
-fig_path = Path(__file__).resolve().parents[2] / "src" / "sleplet" / "figures"
 sns.set(context="paper")
 
 B = 3
@@ -18,9 +14,7 @@ STEP = 0.01
 
 
 def main() -> None:
-    """
-    plots the tiling of the harmonic line
-    """
+    """Plots the tiling of the harmonic line."""
     xlim = L
     x = np.arange(xlim)
     xi = np.arange(0, xlim - 1 + STEP, STEP)
@@ -35,7 +29,11 @@ def main() -> None:
     plt.xticks(ticks, ticks)
     plt.xlabel(r"$\ell$")
     plt.legend(loc=6)
-    save_plot(fig_path, f"axisymmetric_tiling_L{L}")
+    print(f"Opening: axisymmetric_tiling_L{L}")
+    plt.tight_layout()
+    plt.show(block=False)
+    plt.pause(10)
+    plt.close()
 
 
 if __name__ == "__main__":
