@@ -1,17 +1,15 @@
 from numpy.testing import assert_array_equal, assert_raises
 
-from sleplet.functions.flm.earth import Earth
-from sleplet.utils.vars import SMOOTHING
+import sleplet
 
 L = 128
+SMOOTHING = 2
 
 
 def test_smoothing_changes_flm() -> None:
-    """
-    tests the addition of Gaussian noise changes the coefficients
-    """
-    earth = Earth(L)
-    earth_smoothed = Earth(L, smoothing=SMOOTHING)
+    """Tests the addition of Gaussian noise changes the coefficients."""
+    earth = sleplet.functions.Earth(L)
+    earth_smoothed = sleplet.functions.Earth(L, smoothing=SMOOTHING)
     assert_raises(
         AssertionError,
         assert_array_equal,
